/*
 * Copyright (C) 2003-2012 David E. Berry
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * A copy of the GNU Lesser General Public License may also be found at
 * http://www.gnu.org/licenses/lgpl.txt
 */
package org.synchronoss.cpo.helper;

import org.apache.xmlbeans.*;

import java.util.ArrayList;

/**
 *
 * @author dberry
 */
public class XmlBeansHelper {
  public static String validateXml(XmlObject xmlObj) {
    StringBuilder sb = new StringBuilder();
    String errMsg = null;
    ArrayList<XmlValidationError> validationErrors = new ArrayList<XmlValidationError>(); 
    XmlOptions validationOptions = new XmlOptions(); 
    validationOptions.setErrorListener(validationErrors); 
    boolean isValid = xmlObj.validate(validationOptions); // to display error we should pass options.
    if (!isValid) {
      for (XmlValidationError es : validationErrors) {
        sb.append(es.getMessage());
      }
      if (sb.length()>0)
        errMsg=sb.toString();
    }
    return errMsg;
  }

  public static XmlOptions getXmlOptions() {
    XmlOptions xo = new XmlOptions();
    xo.setCharacterEncoding("utf-8");
    xo.setSaveAggressiveNamespaces();
    xo.setSaveNamespacesFirst();
    xo.setSavePrettyPrint();
    xo.setUseDefaultNamespace();
    return xo;
  }
}
